@@ -9,7 +9,7 @@ use File::ReadBackwards;
 use File::HomeDir;
 
 # ABSTRACT: A Log::Log4perl wrapper for use with Clustericious.
-our $VERSION = '1.05'; # VERSION
+our $VERSION = '1.06'; # VERSION
 
 
 sub import {
@@ -19,8 +19,8 @@ sub import {
     if (my $app_name = $args{-init_logging}) {
         init_logging($app_name);
     }
-    no strict 'refs';
-    *{"${dest}::$_"} = *{"${class}::$_"} for qw/TRACE INFO DEBUG ERROR WARN FATAL LOGDIE get_logger/;
+    @_ = ($class, ':easy');
+    goto \&Log::Log4perl::import;
 }
 
 
@@ -113,7 +113,7 @@ Clustericious::Log - A Log::Log4perl wrapper for use with Clustericious.
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head1 SYNOPSIS
 
